==> apache_airflow_providers_github-2.8.2.tar.gz: apache_airflow_providers_github-2.8.2/src/airflow/providers/github/operators/github.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
from __future__ import annotations

from typing import TYPE_CHECKING, Any, Callable

from airflow.exceptions import AirflowException
from airflow.models import BaseOperator
from airflow.providers.github.hooks.github import GithubHook
from github import GithubException

if TYPE_CHECKING:
    try:
        from airflow.sdk.definitions.context import Context
    except ImportError:
        # TODO: Remove once provider drops support for Airflow 2
        from airflow.utils.context import Context


class GithubOperator(BaseOperator):
    """
    Interact and perform actions on GitHub API.

    This operator is designed to use GitHub's Python SDK: https://github.com/PyGithub/PyGithub

    .. seealso::
        For more information on how to use this operator, take a look at the guide:
        :ref:`howto/operator:GithubOperator`

    :param github_conn_id: Reference to a pre-defined GitHub Connection
    :param github_method: Method name from GitHub Python SDK to be called
    :param github_method_args: Method parameters for the github_method. (templated)
    :param result_processor: Function to further process the response from GitHub API
    """

    template_fields = ("github_method_args",)

    def __init__(
        self,
        *,
        github_method: str,
        github_conn_id: str = "github_default",
        github_method_args: dict | None = None,
        result_processor: Callable | None = None,
        **kwargs,
    ) -> None:
        super().__init__(**kwargs)
        self.github_conn_id = github_conn_id
        self.method_name = github_method
        self.github_method_args = github_method_args or {}
        self.result_processor = result_processor

    def execute(self, context: Context) -> Any:
        try:
            # Default method execution is on the top level GitHub client
            hook = GithubHook(github_conn_id=self.github_conn_id)
            resource = hook.client

            github_result = getattr(resource, self.method_name)(**self.github_method_args)
            if self.result_processor:
                return self.result_processor(github_result)

            return github_result

        except GithubException as github_error:
            raise AirflowException(f"Failed to execute GithubOperator, error: {github_error}")
        except Exception as e:
            raise AirflowException(f"GitHub operator error: {e}")

==> apache_airflow_providers_github-2.9.4.tar.gz: apache_airflow_providers_github-2.9.4/src/airflow/providers/github/operators/github.py <==
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
from __future__ import annotations

from collections.abc import Callable
from typing import TYPE_CHECKING, Any

from github import GithubException

from airflow.exceptions import AirflowException
from airflow.providers.common.compat.sdk import BaseOperator
from airflow.providers.github.hooks.github import GithubHook

if TYPE_CHECKING:
    from airflow.providers.common.compat.sdk import Context


class GithubOperator(BaseOperator):
    """
    Interact and perform actions on GitHub API.

    This operator is designed to use GitHub's Python SDK: https://github.com/PyGithub/PyGithub

    .. seealso::
        For more information on how to use this operator, take a look at the guide:
        :ref:`howto/operator:GithubOperator`

    :param github_conn_id: Reference to a pre-defined GitHub Connection
    :param github_method: Method name from GitHub Python SDK to be called
    :param github_method_args: Method parameters for the github_method. (templated)
    :param result_processor: Function to further process the response from GitHub API
    """

    template_fields = ("github_method_args",)

    def __init__(
        self,
        *,
        github_method: str,
        github_conn_id: str = "github_default",
        github_method_args: dict | None = None,
        result_processor: Callable | None = None,
        **kwargs,
    ) -> None:
        super().__init__(**kwargs)
        self.github_conn_id = github_conn_id
        self.method_name = github_method
        self.github_method_args = github_method_args or {}
        self.result_processor = result_processor

    def execute(self, context: Context) -> Any:
        try:
            # Default method execution is on the top level GitHub client
            hook = GithubHook(github_conn_id=self.github_conn_id)
            resource = hook.client

            github_result = getattr(resource, self.method_name)(**self.github_method_args)
            if self.result_processor:
                return self.result_processor(github_result)

            return github_result

        except GithubException as github_error:
            raise AirflowException(f"Failed to execute GithubOperator, error: {github_error}")
        except Exception as e:
            raise AirflowException(f"GitHub operator error: {e}")
